Learn R Programming

rappleads (version 0.1.3)

apl_get_client_secret: Get client secret

Description

Get client secret

Usage

apl_get_client_secret(
  client_id,
  team_id,
  key_id,
  private_key_path,
  account_name,
  cache_path = rappdirs::site_data_dir("rappleads")
)

Value

jwt_data

Arguments

client_id

You receive your clientId when you upload a public key.

team_id

The client secret is a JWT that you create and sign with your private key.

key_id

The value is your keyId that returns when you upload a public key.

private_key_path

Path to the .pem file containing your private key.

account_name

Your apple ads account name

cache_path

Path to the directory where cached authentication data will be stored.