Get client secret
apl_get_client_secret(
client_id,
team_id,
key_id,
private_key_path,
account_name,
cache_path = rappdirs::site_data_dir("rappleads")
)jwt_data
You receive your clientId when you upload a public key.
The client secret is a JWT that you create and sign with your private key.
The value is your keyId that returns when you upload a public key.
Path to the .pem file containing your private key.
Your apple ads account name
Path to the directory where cached authentication data will be stored.